==> kubernetes-model-gatewayapi-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GatewayFluentImpl<A extends GatewayFluent<A>> extends BaseFluent<A> implements GatewayFluent<A>{
  public GatewayFluentImpl() {
  }
  public GatewayFluentImpl(Gateway instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private GatewaySpecBuilder spec;
  private GatewayStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public GatewayFluent.MetadataNested<A> withNewMetadata() {
    return new GatewayFluentImpl.MetadataNestedImpl();
  }
  public GatewayFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new GatewayFluentImpl.MetadataNestedImpl(item);
  }
  public GatewayFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public GatewayFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public GatewayFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewaySpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public GatewaySpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(GatewaySpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new GatewaySpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public GatewayFluent.SpecNested<A> withNewSpec() {
    return new GatewayFluentImpl.SpecNestedImpl();
  }
  public GatewayFluent.SpecNested<A> withNewSpecLike(GatewaySpec item) {
    return new GatewayFluentImpl.SpecNestedImpl(item);
  }
  public GatewayFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public GatewayFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new GatewaySpecBuilder().build());
  }
  public GatewayFluent.SpecNested<A> editOrNewSpecLike(GatewaySpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewayStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public GatewayStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(GatewayStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new GatewayStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public GatewayFluent.StatusNested<A> withNewStatus() {
    return new GatewayFluentImpl.StatusNestedImpl();
  }
  public GatewayFluent.StatusNested<A> withNewStatusLike(GatewayStatus item) {
    return new GatewayFluentImpl.StatusNestedImpl(item);
  }
  public GatewayFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public GatewayFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new GatewayStatusBuilder().build());
  }
  public GatewayFluent.StatusNested<A> editOrNewStatusLike(GatewayStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GatewayFluentImpl that = (GatewayFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<GatewayFluent.MetadataNested<N>> implements GatewayFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) GatewayFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends GatewaySpecFluentImpl<GatewayFluent.SpecNested<N>> implements GatewayFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(GatewaySpec item) {
      this.builder = new GatewaySpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new GatewaySpecBuilder(this);
    }
    GatewaySpecBuilder builder;
    public N and() {
      return (N) GatewayFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends GatewayStatusFluentImpl<GatewayFluent.StatusNested<N>> implements GatewayFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(GatewayStatus item) {
      this.builder = new GatewayStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new GatewayStatusBuilder(this);
    }
    GatewayStatusBuilder builder;
    public N and() {
      return (N) GatewayFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GatewayFluentImpl<A extends GatewayFluent<A>> extends BaseFluent<A> implements GatewayFluent<A>{
  public GatewayFluentImpl() {
  }
  public GatewayFluentImpl(Gateway instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private GatewaySpecBuilder spec;
  private GatewayStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public GatewayFluentImpl.MetadataNested<A> withNewMetadata() {
    return new GatewayFluentImpl.MetadataNestedImpl();
  }
  public GatewayFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new GatewayFluentImpl.MetadataNestedImpl(item);
  }
  public GatewayFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public GatewayFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public GatewayFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewaySpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public GatewaySpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(GatewaySpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new GatewaySpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public GatewayFluentImpl.SpecNested<A> withNewSpec() {
    return new GatewayFluentImpl.SpecNestedImpl();
  }
  public GatewayFluentImpl.SpecNested<A> withNewSpecLike(GatewaySpec item) {
    return new GatewayFluentImpl.SpecNestedImpl(item);
  }
  public GatewayFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public GatewayFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new GatewaySpecBuilder().build());
  }
  public GatewayFluentImpl.SpecNested<A> editOrNewSpecLike(GatewaySpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewayStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public GatewayStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(GatewayStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new GatewayStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public GatewayFluentImpl.StatusNested<A> withNewStatus() {
    return new GatewayFluentImpl.StatusNestedImpl();
  }
  public GatewayFluentImpl.StatusNested<A> withNewStatusLike(GatewayStatus item) {
    return new GatewayFluentImpl.StatusNestedImpl(item);
  }
  public GatewayFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public GatewayFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new GatewayStatusBuilder().build());
  }
  public GatewayFluentImpl.StatusNested<A> editOrNewStatusLike(GatewayStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GatewayFluentImpl that = (GatewayFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<GatewayFluentImpl.MetadataNested<N>> implements GatewayFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) GatewayFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends GatewaySpecFluentImpl<GatewayFluentImpl.SpecNested<N>> implements GatewayFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(GatewaySpec item) {
      this.builder = new GatewaySpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new GatewaySpecBuilder(this);
    }
    GatewaySpecBuilder builder;
    public N and() {
      return (N) GatewayFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends GatewayStatusFluentImpl<GatewayFluentImpl.StatusNested<N>> implements GatewayFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(GatewayStatus item) {
      this.builder = new GatewayStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new GatewayStatusBuilder(this);
    }
    GatewayStatusBuilder builder;
    public N and() {
      return (N) GatewayFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
